# stawp

STAtic Website Producer

Simple modular static site generator that only does what you need.

## Examples

* [Basic behavior](https://github.com/polishmatt/stawp/tree/master/tests/fixtures/builder)

